# Atomistic Global Optimization X (AGOX)

![logo](docs/source/logos/logo-carbon.gif)


AGOX is a package for global optimization of atomic system using e.g. the energy 
calculated from density functional theory as the objective function. AGOX interfaces 
with the Atomistic Simulation Environment (ASE) and as such supports any of 
calculators in ASE as objectives for optimization. 

AGOX is built to be flexible, consisting of modules that can be put together to 
create an optimization algorithm, from simple random searches to Bayesian searches 
guided by a surrogate model and many more. 

Check out the documentation at 

https://agox.gitlab.io/agox/

# Contributions & Issues 

Feel free to make a fork and submit a merge request! 

If you have an issue or a question please post it on the issue board! 

# Authors 

The main AGOX framework has been written by 
* Mads-Peter Verner Christiansen
* Nikolaj Rønne
* Bjørk Hammer

with inspiration and help from current and previous members of the Hammer group at Aarhus University, Denmark.
Parts of the code have been contributed by

* Andreas Slavensky (Complementary Energy Generator)

# License

AGOX is released under the GPLv3 license. 


